Learn R Programming

avesperu (version 0.0.6)

.onAttach: .onAttach hook

Description

Hook function that runs when the package is attached via library(). It displays the package version and checks for UNOP checklist updates.

Usage

.onAttach(lib, pkg)

Arguments

lib

A character string indicating the path to the library.

pkg

A character string with the name of the package.