Learn R Programming

avesperu (version 0.0.6)

.onLoad: .onLoad hook

Description

Hook function that runs when the package is loaded. It sets default options for the package.

Usage

.onLoad(libname, pkgname)

Arguments

libname

A character string with the name of the library directory.

pkgname

A character string with the name of the package.