Learn R Programming

avesperu (version 0.0.6)

unop_update_date: Get Last Update Date from UNOP Checklist Website

Description

This function scrapes the "Boletin UNOP" checklist page and extracts the last update date mentioned in the text.

Usage

unop_update_date()

Arguments

Value

A character string with the date in the format "dd de mes de yyyy", or NA if no date is found.