powered by
Hook function that runs when the package is attached via library(). It displays the package version and checks for UNOP checklist updates.
library()
.onAttach(lib, pkg)
A character string indicating the path to the library.
A character string with the name of the package.