Learn R Programming

avesperu (version 0.0.6)

unop_check_update: Check if the UNOP Checklist Has Been Updated

Description

This function compares the latest update date from the UNOP checklist website with a reference version date. It returns a message indicating whether an update has occurred.

Usage

unop_check_update(version_date = "23 de junio de 2025")

Value

A character message indicating if the site has a more recent update.

Arguments

version_date

Character string with the current local version date (e.g., "05 de abril de 2025").